@@ -351,6 +351,26 @@ class LocalPorvider(BaseProvider):
         """
         return TDP.daily_shszchholdings(instruments, fields, start_date, end_date)
 
+    def daily_indexvaluation(self, instruments: list, fields: list, start_date: str = defualt_start_date,
+                              end_date: str = defualt_end_date):
+        """
+            table_name: 'AIndexValuation'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: return
+        """
+        return TDP.daily_indexvaluation(instruments, fields, start_date, end_date)
+
+    def daily_cbindexeodprices(self, instruments: list, fields: list, start_date: str = defualt_start_date,
+                              end_date: str = defualt_end_date):
+        """
+            table_name: 'CBIndexEODPrices'
+            input: instruments,start_date,end_date
+            output: DataFrame
+            fields: return
+        """
+        return TDP.daily_cbindexeodprices(instruments, fields, start_date, end_date)
+
     def daily_indexweight(self, instruments, **kws):
         """
             table_name: 'AIndexFreeWeight'
@@ -427,6 +447,16 @@ class LocalPorvider(BaseProvider):
         """
         return InstSP.suntime_typedict(organid, fields)
 
+    def cfutures_contract_mapping(self, organid=None, fields=None):
+        """ 
+            table_name: 'CFuturesContractMapping'
+            input:instruments:List(str),fields:List(str)
+                  optional: stkcode = None,fields =None
+            output: DataFrame
+            fields : suspend_date,resump_date           
+        """
+        return InstSP.cfutures_contract_mapping(organid, fields)
+
     def Industrycompo_citics(self, stockcode=None, level=None):
         """  
             table_name: "AShareIndustriesClass_CITICS"
