@@ -34,10 +34,13 @@ aindex_eod_price = os.path.join(data_path,r'AIndexEODPrices')
 aindex_idueodcitics = os.path.join(data_path,r'AIndexIndustriesEODCITICS')
 aindex_freeweight = os.path.join(data_path,r'AIndexFreeWeight')
 cmf_indexeod = os.path.join(data_path,r"CMFIndexEOD")
-
+indexvaluation = os.path.join(data_path,r"AIndexValuation")
 
 shszchholdings = os.path.join(data_path, r"SHSCChannelholdings")
 shszstockholding = os.path.join(data_path,r"SHSZstockhoding")
+
+cbindexeodprices = os.path.join(data_path,r"CBIndexEODPrices")
+
 #%%
 class BaseDailyTSInfoProvider(abc.ABC):
 
@@ -146,6 +149,14 @@ class TradeDayInfoProvider(BaseDailyTSInfoProvider):
     @print_func_time
     def get_daily_shsz_stkholding(self,instruments,fields,start_date,end_date):
         return self.get_daily_data(shszstockholding,instruments,fields = fields ,start_date = start_date,end_date = end_date)
+    
+    @print_func_time
+    def daily_indexvaluation(self, instruments,fields,start_date,end_date):
+        return self.get_daily_data(indexvaluation,instruments,fields = fields ,start_date = start_date,end_date = end_date)
+
+    @print_func_time
+    def daily_cbindexeodprices(self, instruments,fields,start_date,end_date):
+        return self.get_daily_data(cbindexeodprices,instruments,fields = fields ,start_date = start_date,end_date = end_date)
 
     @print_func_time
     def get_daily_indexweight(self,instruments,**kws):
@@ -169,5 +180,9 @@ class TradeDayInfoProvider(BaseDailyTSInfoProvider):
     def daily_shszchholdings(self, instruments,fields,start_date,end_date):
         return self.get_sparse_daily_data(shszchholdings,instruments,fields = fields ,start_date = start_date,end_date = end_date)
 
+
+
+
+
 if __name__ == '__main__':
     TradeDayInfoProvider().get_daily_indexweight()
\ No newline at end of file
